@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Crypt::OpenSSL::X509();
 use Crypt::OpenSSL::RSA();
-use Crypt::OpenSSL::PKCS10();
+use Crypt::PKCS10();
 use Convert::ASN1();
 use Digest();
 use MIME::Base64();
@@ -22,7 +22,7 @@ our %EXPORT_TAGS = ( 'all' => \@EXPORT_OK, );
 sub _CERTIFICATE_HEADER_SIZE { return 40; }
 sub _MAX_PUBLIC_KEY_SIZE     { return 65_536; }
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 sub pin_sha256 {
     my ($path) = @_;
@@ -63,6 +63,8 @@ sub pin_sha256 {
           _check_for_der_encoded_x509_certificate( $handle, $file_header,
             $path )
           || _check_for_der_encoded_private_key( $handle, $file_header, $path )
+          || _check_for_der_pkcs10_certificate_request( $handle, $file_header,
+            $path )
           || _check_for_der_encoded_public_key( $handle, $file_header, $path );
         if ( !defined $pem_encoded_public_key_string ) {
             Carp::croak("$path is not an X.509 Certificate");
@@ -110,8 +112,31 @@ s/^([-]{5}BEGIN[ ])(?:X[.]?509|TRUSTED)[ ](CERTIFICATE[-]{5})/$1$2/smx;
 
 sub _process_pem_pkcs10_certificate_request {
     my ( $handle, $file_header, $path ) = @_;
-    my $req = Crypt::OpenSSL::PKCS10->new_from_file($path);
-    my $pem_encoded_public_key_string = $req->get_pem_pubkey();
+    seek $handle, 0, Fcntl::SEEK_SET()
+      or Carp::croak("Failed to seek to start of $path:$EXTENDED_OS_ERROR");
+    defined read $handle, my $pkcs10_certificate_string, _MAX_PUBLIC_KEY_SIZE()
+      or Carp::croak("Failed to read from $path:$EXTENDED_OS_ERROR");
+    Crypt::PKCS10->setAPIversion(1);
+    my $req = Crypt::PKCS10->new($pkcs10_certificate_string);
+    my $pem_encoded_public_key_string = $req->subjectPublicKey(1);
+    return $pem_encoded_public_key_string;
+}
+
+sub _check_for_der_pkcs10_certificate_request {
+    my ( $handle, $file_header, $path ) = @_;
+    my $pem_encoded_public_key_string;
+    eval {
+        seek $handle, 0, Fcntl::SEEK_SET()
+          or Carp::croak("Failed to seek to start of $path:$EXTENDED_OS_ERROR");
+        defined read $handle, my $pkcs10_certificate_string,
+          _MAX_PUBLIC_KEY_SIZE()
+          or Carp::croak("Failed to read from $path:$EXTENDED_OS_ERROR");
+        Crypt::PKCS10->setAPIversion(1);
+        my $req = Crypt::PKCS10->new($pkcs10_certificate_string);
+        $pem_encoded_public_key_string = $req->subjectPublicKey(1);
+    } or do {
+        return;
+    };
     return $pem_encoded_public_key_string;
 }
 
